Crate portunusd

CrateRepoTweets

PortunusD is a network application server, inspired by relayd and inetd, which aims to ease the scaling of single-threaded request/response-style applications: web applications, DNS queries, etc. PortunusD allows applications to embrace the “serverless” style of development, but without throwing away all the luxuries of the operating system.

Modules

  • Define connection handlers for your PortunusD Apps!
  • illumos-specific APIs not (yet) found in the libc crate

Macros